The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Package {rmsfact}


Type: Package
Title: Amazing Random Facts About the World's Greatest Hacker
Version: 0.0.4
Date: 2026-09-11
Description: Display a randomly selected quote about Richard M. Stallman based on the collection in the 'GNU Octave' function 'fact()' which was aggregated by Jordi GutiƩrrez Hermoso based on the (now defunct) site stallmanfacts.com (which is accessible only via http://archive.org).
URL: https://github.com/eddelbuettel/rmsfact
BugReports: https://github.com/eddelbuettel/rmsfact/issues
License: GPL-3
Encoding: UTF-8
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2026-09-11 14:04:30 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre], Octave Authors [aut]
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-09-11 14:30:02 UTC

Display a Random Fact about Richard M. Stallman

Description

Function to display a randomly chosen fact about Richard M. Stallman

Usage

rmsfact(ind)

## S3 method for class 'rmsfact'
print(x, width = NULL, ...)

Arguments

ind

Optional index of a quote, or character expression to be matched; if missing a random index value is sampled

x

Default object for print method

width

Optional column width parameter

...

Other optional arguments

Details

This function displays a randomly chosen line from the included data set of of random ‘facts’ about Richard M. Stallman. The function is a port of the GNU Octave function fact doing the same, and written by Jordi GutiĆ©rrez Hermoso based on the (now defunct) site stallmanfacts.com.

Value

A character vector containing one randomly selected line from the included file. It is of class rmsfact for which an S3 print method will be invoked.

Author(s)

Dirk Eddelbuettel

See Also

fortune

Examples

  set.seed(123)
  rmsfact()

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.